from django.contrib.auth.models import AbstractUser
from django.db import models
from django.contrib.auth import get_user_model


class UserManager(models.Manager):
    def all(self):
        return super().all().filter(is_active=True)

    def restore(self):
        return self.get_queryset().update(is_active=True)

    def delete(self):
        # Article.objects.delete()
        return self.get_queryset().update(is_active=False)


class User(AbstractUser):
    objects = UserManager()


class Profile(models.Model):
    user = models.OneToOneField(
        get_user_model(),
        related_name='profile',
        on_delete=models.CASCADE,
        verbose_name='Пользователь'
    )
    birth_date = models.DateTimeField(null=True, blank=True, verbose_name='Дата рождения')
    avatar = models.ImageField(null=True, blank=True, upload_to='avatars', verbose_name='Аватар')

    def __str__(self):
        return self.user.username + "'s Profile"

    class Meta:
        verbose_name = 'Профиль'
        verbose_name_plural = 'Профили'
