from rest_framework import serializers

from web.models import StatusChoices, Article


class ArticleSerializer(serializers.ModelSerializer):
    class Meta:
        model = Article
        fields = ['id', 'title', 'text', 'author', 'status', 'created_at', 'updated_at']
        read_only_fields = ['author', 'id', 'created_at', 'updated_at']


class ArticlePartialUpdateSerializer(serializers.ModelSerializer):
    title = serializers.CharField(max_length=200, required=False)
    text = serializers.CharField(max_length=3000, required=False)

    class Meta:
        model = Article
        fields = ['id', 'title', 'text', 'author', 'status', 'created_at', 'updated_at']


class ArticleSerializerOld(serializers.Serializer):
    id = serializers.IntegerField(read_only=True)
    title = serializers.CharField(max_length=200, required=True)
    text = serializers.CharField(max_length=3000, required=True)
    author = serializers.PrimaryKeyRelatedField(read_only=True)
    status = serializers.ChoiceField(choices=StatusChoices.choices, required=False)
    created_at = serializers.DateTimeField(read_only=True)
    updated_at = serializers.DateTimeField(read_only=True)

    def create(self, validated_data):
        return Article.objects.create(**validated_data)

    def update(self, instance, validated_data):
        for k, v in validated_data.items():
            setattr(instance, k, v)

        instance.save()
        return instance
